##
##  prometheus-statsd.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_prometheus_statsd_base 0.26.0
%define       V_prometheus_statsd_snap 20240107

#   package information
Name:         prometheus-statsd
Summary:      Bridge between StatsD and Prometheus
URL:          https://github.com/prometheus/statsd_exporter
Vendor:       Matt T. Proud, Julius Volz
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      Apache
Version:      %{V_prometheus_statsd_base}.%{V_prometheus_statsd_snap}
Release:      20240107

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/prometheus/prometheus-statsd-%{V_prometheus_statsd_snap}.tar.xz
Source1:      rc.prometheus-statsd
Source2:      prometheus-statsd.conf

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    This is the Prometheus StatsD Bridge. It receives StatsD-style
    metrics and exports them as Prometheus metrics service.

%track
    prog prometheus-statsd:release = {
        version   = %{V_prometheus_statsd_base}
        url       = https://github.com/prometheus/statsd_exporter/releases
        regex     = (__VER__)\.tar\.gz
    }
    prog prometheus-statsd:snapshot = {
        version   = %{V_prometheus_statsd_snap}
        url       = http://download.openpkg.org/components/versioned/prometheus/
        regex     = prometheus-statsd-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n prometheus-statsd

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/prometheus/statsd_exporter
    go build -x -o bin/prometheus-statsd .

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/prometheus-statsd \
        $RPM_BUILD_ROOT%{l_prefix}/var/prometheus-statsd/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/prometheus-statsd/run

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/prometheus/statsd_exporter/bin/prometheus-statsd \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/prometheus-statsd

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE prometheus-statsd.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/prometheus-statsd/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.prometheus-statsd} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/prometheus-statsd/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/prometheus-statsd/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} prometheus-statsd status 2>/dev/null`
    [ ".$prometheus_statsd_active" = .yes ] && %{l_rc} prometheus-statsd restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} prometheus-statsd stop 2>/dev/null
    rm -rf $RPM_INSTALL_PREFIX/var/prometheus-statsd/log/*  >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/prometheus-statsd/run/*  >/dev/null 2>&1 || true
    exit 0

